==> kubernetes-model-policy-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/HostPortRangeFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HostPortRangeFluent<A extends HostPortRangeFluent<A>> extends BaseFluent<A>{
  public HostPortRangeFluent() {
  }
  public HostPortRangeFluent(HostPortRange instance) {
    instance = (instance != null ? instance : new HostPortRange());

    if (instance != null) {
      this.withMax(instance.getMax());
      this.withMin(instance.getMin());
      this.withMax(instance.getMax());
      this.withMin(instance.getMin());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer max;
  private Integer min;
  private Map<String,Object> additionalProperties;
  public Integer getMax() {
    return this.max;
  }
  public A withMax(Integer max) {
    this.max=max; return (A) this;
  }
  public boolean hasMax() {
    return this.max != null;
  }
  public Integer getMin() {
    return this.min;
  }
  public A withMin(Integer min) {
    this.min=min; return (A) this;
  }
  public boolean hasMin() {
    return this.min != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HostPortRangeFluent that = (HostPortRangeFluent) o;
    if (!java.util.Objects.equals(max, that.max)) return false;

    if (!java.util.Objects.equals(min, that.min)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(max,  min,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (max != null) { sb.append("max:"); sb.append(max + ","); }
    if (min != null) { sb.append("min:"); sb.append(min + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-policy-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/HostPortRangeFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HostPortRangeFluent<A extends HostPortRangeFluent<A>> extends BaseFluent<A>{
  public HostPortRangeFluent() {
  }
  
  public HostPortRangeFluent(HostPortRange instance) {
    this.copyInstance(instance);
  }
  private Integer max;
  private Integer min;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HostPortRange instance) {
    instance = (instance != null ? instance : new HostPortRange());
  
    if (instance != null) {
        this.withMax(instance.getMax());
        this.withMin(instance.getMin());
        this.withMax(instance.getMax());
        this.withMin(instance.getMin());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Integer getMax() {
    return this.max;
  }
  
  public A withMax(Integer max) {
    this.max=max; return (A) this;
  }
  
  public boolean hasMax() {
    return this.max != null;
  }
  
  public Integer getMin() {
    return this.min;
  }
  
  public A withMin(Integer min) {
    this.min=min; return (A) this;
  }
  
  public boolean hasMin() {
    return this.min != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HostPortRangeFluent that = (HostPortRangeFluent) o;
    if (!java.util.Objects.equals(max, that.max)) return false;
  
    if (!java.util.Objects.equals(min, that.min)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(max,  min,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (max != null) { sb.append("max:"); sb.append(max + ","); }
    if (min != null) { sb.append("min:"); sb.append(min + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
